@@ -16,9 +16,8 @@ def test_get_api_key_missing():
     with patch.dict(os.environ, {}, clear=True):
         with pytest.raises(EnvironmentError) as exc_info:
             get_api_key()
-        assert (
-            str(exc_info.value)
-            == "Neither OPENROUTER_API_KEY nor OPENAI_API_KEY environment variable is set."
+        assert str(exc_info.value) == (
+            "Neither OPENROUTER_API_KEY nor OPENAI_API_KEY environment variable is set."
         )
 
 
@@ -42,9 +41,8 @@ def test_get_api_key_neither_key():
     with patch.dict(os.environ, {}, clear=True):
         with pytest.raises(EnvironmentError) as exc_info:
             get_api_key()
-        assert (
-            str(exc_info.value)
-            == "Neither OPENROUTER_API_KEY nor OPENAI_API_KEY environment variable is set."
+        assert str(exc_info.value) == (
+            "Neither OPENROUTER_API_KEY nor OPENAI_API_KEY environment variable is set."
         )
 
 
@@ -52,9 +50,10 @@ def test_main_environment_error():
     with (
         patch("git_llm_commit.load_dotenv"),
         patch("git_llm_commit.get_api_key", side_effect=EnvironmentError("Test error")),
+        patch("sys.argv", ["git-llm-commit"]),
     ):
         with pytest.raises(SystemExit) as exc_info:
-            main()
+            main([])
         assert exc_info.value.code == 1
 
 
@@ -66,7 +65,7 @@ def test_main_unexpected_error():
         patch("git_llm_commit.llm_commit", side_effect=RuntimeError("Test error")),
     ):
         with pytest.raises(SystemExit) as exc_info:
-            main()
+            main([])
         assert exc_info.value.code == 1
 
 
@@ -77,12 +76,46 @@ def test_main_success():
         patch("git_llm_commit.llm_commit") as mock_llm_commit,
         patch("git_llm_commit.load_dotenv"),
     ):
-        main()
-        mock_llm_commit.assert_called_once_with(api_key=test_key)
+        main([])
+        mock_llm_commit.assert_called_once_with(api_key=test_key, dynamic_length=False)
 
 
 def test_main_missing_key():
     with patch.dict(os.environ, {}, clear=True), patch("git_llm_commit.load_dotenv"):
         with pytest.raises(SystemExit) as exc_info:
-            main()
+            main([])
         assert exc_info.value.code == 1
+
+
+def test_main_with_dynamic_flag():
+    test_key = "test-api-key"
+    with (
+        patch.dict(os.environ, {"OPENAI_API_KEY": test_key}),
+        patch("git_llm_commit.llm_commit") as mock_llm_commit,
+        patch("git_llm_commit.load_dotenv"),
+    ):
+        main(["--dynamic"])
+        mock_llm_commit.assert_called_once_with(api_key=test_key, dynamic_length=True)
+
+
+def test_main_with_short_dynamic_flag():
+    test_key = "test-api-key"
+    with (
+        patch.dict(os.environ, {"OPENAI_API_KEY": test_key}),
+        patch("git_llm_commit.llm_commit") as mock_llm_commit,
+        patch("git_llm_commit.load_dotenv"),
+    ):
+        main(["-d"])
+        mock_llm_commit.assert_called_once_with(api_key=test_key, dynamic_length=True)
+
+
+def test_main_without_dynamic_flag():
+    test_key = "test-api-key"
+    with (
+        patch.dict(os.environ, {"OPENAI_API_KEY": test_key}),
+        patch("git_llm_commit.llm_commit") as mock_llm_commit,
+        patch("git_llm_commit.load_dotenv"),
+        patch("sys.argv", ["git-llm-commit"]),
+    ):
+        main([])
+        mock_llm_commit.assert_called_once_with(api_key=test_key, dynamic_length=False)
